@@ -1,7 +1,7 @@
 /***************************************************************************
  *
  * Copyright (c) 1999 Balzs Scheidler
- * Copyright (c) 1999 BalaBit Computing
+ * Copyright (c) 1999-2001 BalaBit IT Ltd.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.31.2.1 2000/11/29 11:04:29 bazsi Exp $
+ * $Id: affile.c,v 1.31.2.2 2001/02/25 12:30:22 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -215,8 +215,10 @@ do_init_dest_writer(struct log_handler *c, struct syslog_config *cfg, struct per
 				 NULL);
 		self->res = REMEMBER_RESOURCE(cfg->resources, &self->dest->super.super);
 		self->time_reap = cfg->time_reap;
-		if ((self->owner->flags & AFFILE_NO_EXPAND) == 0)
+		if ((self->owner->flags & AFFILE_NO_EXPAND) == 0) {
 			self->reap = io_callout(cfg->backend, cfg->time_reap, make_affile_dest_reaper(cfg, self));
+			io_callout_set_drop(self->reap, 0);
+		}
 		/* self->attempts = 0; */
 	}
 	else {
