@@ -1,7 +1,7 @@
 /***************************************************************************
  *
  * Copyright (c) 1999 Balzs Scheidler
- * Copyright (c) 1999 BalaBit Computing
+ * Copyright (c) 1999-2001 BalaBit IT Ltd.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.14.4.1 2000/11/29 11:04:29 bazsi Exp $
+ * $Id: afunix.c,v 1.14.4.3 2001/02/25 12:30:22 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -272,7 +272,9 @@ do_destroy_afunix_source(struct log_handler *c,
 		struct persistent_info *p;
 
 		p = make_persistent_info
-			(c_format("afunix_%S", unix_addr->path),
+			(c_format("afunix_%z_%S", 
+			          self->super.flags & AFSOCKET_DGRAM ? "dgram" : "stream",
+			          unix_addr->path),
 			 &self->super.connections->super, 
 			 NULL);
 		add_persistent_info(persistent, p);
