@@ -1,7 +1,7 @@
 /***************************************************************************
  *
  * Copyright (c) 1999 Balzs Scheidler
- * Copyright (c) 1999 BalaBit Computing
+ * Copyright (c) 1999-2001 BalaBit IT Ltd.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.27.2.1 2000/11/29 11:04:29 bazsi Exp $
+ * $Id: main.c,v 1.27.2.2 2001/02/25 12:30:22 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -93,7 +93,7 @@ static void do_reread_config(struct callback *c)
 		}
 		else {
 			/* this is a fatal error, but no stderr & no log output */
-			exit(137);
+			exit(127);
 		}
 		kill_persistent_config(self->backend->persistent);
 		self->backend->persistent = NULL;
@@ -150,11 +150,6 @@ int main_loop(struct syslog_backend *backend)
 			break;
 		if (sighuprecvd && !restarting) {
 
-		       	FOR_QUEUE(&backend->super.callouts, struct ol_queue_node *, n) {
-        			ol_queue_remove(n);
-       				ol_space_free(n);
-	        	}
-
 			notice("SIGHUP received, restarting syslog-ng\n");
 			restarting = 1;
 
@@ -163,6 +158,7 @@ int main_loop(struct syslog_backend *backend)
 				static struct reread_config r = 
 				{ { STATIC_HEADER, do_reread_config }, NULL, 0 };
 				
+				io_callout_flush(&backend->super);
 				r.backend = backend;
 				r.state = 0;
 				io_callout(&backend->super, 0, &r.super);
